@@ -1866,20 +1866,38 @@ sunone_connection_search_calids (SunOneConnection *connection, SunOneSearchField
 	soup_uri_free (get_uri);
 
 	if (SUNONE_ERROR_IS_SUCCESSFUL (msg->status_code)) {
-		icalcomp = sunone_util_icalparser_parse_string (msg->response.body, msg->response.length);
-		if (icalcomp) {
-			subcomp = icalcomponent_get_first_component (icalcomp, ICAL_VCALENDAR_COMPONENT);
-			while (subcomp) {
-				calprops = calprops_from_icalcomp (subcomp);
-				if (calprops)
-					calids = g_list_append (calids, calprops);
+		char *tmp_str;
+		char *vcal_str;
 
-				subcomp = icalcomponent_get_next_component (icalcomp, ICAL_VCALENDAR_COMPONENT);
+		tmp_str = g_strndup (msg->response.body, msg->response.length);
+		if (tmp_str) {
+			vcal_str = g_strdup_printf ("BEGIN:VCALENDAR\n%s\nEND:VCALENDAR\n", tmp_str);
+			g_free (tmp_str);
+			if (vcal_str) {
+				icalcomp = sunone_util_icalparser_parse_string (vcal_str, strlen (vcal_str));
+				g_free (vcal_str);
+				if (icalcomp) {
+					subcomp = icalcomponent_get_first_component (icalcomp, ICAL_VCALENDAR_COMPONENT);
+					while (subcomp) {
+						/* Because we wrap the result in a vcalender,
+						 * we always get at least one sub component in icalcompoent.
+						 * So we use ICAL_X_PROPERTY to identify if this sub component
+						 * is the only one in search result or it is just fake.
+						 */
+						if (icalcomponent_get_first_property (subcomp, ICAL_X_PROPERTY) != NULL) {
+							calprops = calprops_from_icalcomp (subcomp);
+							if (calprops)
+								calids = g_list_append (calids, calprops);
+						}
+
+						subcomp = icalcomponent_get_next_component (icalcomp, ICAL_VCALENDAR_COMPONENT);
+					}
+
+					icalcomponent_free (icalcomp);
+				} else
+					g_warning ("Error: could not parse response's body");
 			}
-
-			icalcomponent_free (icalcomp);
-		} else
-			g_warning ("Error: could not parse response's body");
+		}
 	} else
 		g_warning ("Error: %s", msg->reason_phrase);
 
